API docs for “spamfighter.core.test.test_counters.AtomCounterEternalTestCase”

# Class s.c.t.t.AtomCounterEternalTestCase(unittest.TestCase):

Part of spamfighter.core.test.test_counters View Source View In Hierarchy

Тест на `spamfighter.core.counters.AtomCounterEternal`.

Method | testInterface | Undocumented
Method | testLabel | Undocumented
Method | testIncrement | Undocumented
Method | testPeriod | Undocumented

def testInterface(self): (source)
Undocumented
def testLabel(self): (source)
Undocumented
def testIncrement(self): (source)
Undocumented
def testPeriod(self): (source)
Undocumented